function [PP,RR] = TF(data,srate,tlim,winSize,numWin,wavCyc,padratio);


%function [PP,RR] = TF(data,srate,tlim,winSize,numWin,wavCyc,padratio,naccu);
%
% Creates spectrogram of data.  
%
% Based on the function 'timef' in the EEGLab-toolbox written by Sigurd Enghoff, Arnaud
% Delorme and Scott Makeig [GNU public license].
% 
% Inputs:
%
% 1.) data: the data vector
% 2.) srate: the sampling rate
% 3.) tlim: the timelimits in which the data was taken e.g. [-500 1998]. Important for
% baseline correction of EEG data.
% 4.) winSize: the size of the sliding windows
% 5.) numWin: how often do you want to apply the window on the data
% 6.) wavCyc: if 0 then normal FFT, else if e.g. [3 1] then we have a
% wavelet window with 3 cycles and 
% 7.) padratio: the factor for zero-padding. Default is 2, i.e. each data
% window length is doubled by adding zeros.
% 8.) naccu: the number of bootstrap samples drawn randomly with replacement for each trial
%
% Outputs:
% 1.) PP: the power spectrum 
% 2.) RR: the phase information
% 3.) Pboot: the bootstrap power samples
% 4.) Rboot: the bootstrap phase samples
% 5,) cumulXboot:
% modified by HPF Jan 2006.
% modified by cmuehl Feb 2006.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Definitions
maxfreq = 45;
g.type = 'phasecoher';  % ???
% sprintf(['The', g.type, 'will be calculated for the ITC.'])

% Check inputs
switch(nargin) 
    case 7
        % sprintf('All arguments specified.')
    case 6
        padratio = 2; % pad to double length
    case 5
        padratio = 2;
        wavCyc = [3 0.5]; % we use a wavelet window
    case 4
        padratio = 2;
        wavCyc = [3 0.5];
        numWin = 200;
    case 3
        padratio = 2;
        wavCyc = [3 0.5];
        numWin = 200;
        winSize = 250;
    otherwise
        error('Please specify data, sampling rate and timelimits');
end %switch(nargin)

if (~isnumeric(padratio) | length(padratio)~=1 | padratio~=round(padratio))
	error('Value of padratio must be an integer.');
elseif (padratio <= 0)
	error('Value of padratio must be positive.');
elseif (pow2(nextpow2(padratio)) ~= padratio)
	error('Value of padratio must be an integer power of two [1,2,4,8,16,...]');
end

% computing the time-vector (do we need it? nooot here..)
wintime = 1000/srate*(winSize/2); 
times = [tlim(1)+wintime:(tlim(2)-tlim(1)-2*wintime)/(numWin-1):tlim(2)-wintime];

stp = (length(data)-winSize)/(numWin-1);

% Do the windowing
for tstep = 1:numWin

    % pull out data window
    tmpX = data([1:winSize]+floor((tstep-1)*stp));
    % remove the mean for that window
    tmpX = tmpX - mean(tmpX);

    if ~any(isnan(tmpX))

        if (wavCyc(1) == 0) % FFT
            
        sprintf(' no FFT possible with this TF - function ')
        
        else % Wavelet decomposition

            % Calculate, which frequencies you are theoretically able to
            % represent
            freqs = srate*wavCyc(1)/winSize*[2:2/padratio:winSize]/2;
            % Chose the ones that are in the range you are interested in
            dispf = find(freqs <= maxfreq);
            freqs = freqs(dispf);
            % Create the complex wavelet
            win = dftfilt(winSize,maxfreq/srate,wavCyc(1),padratio,wavCyc(2));
            tmpX = transpose(win) * tmpX(:);
            PP(:,tstep) = abs(tmpX).^2; % POWER
            switch g.type
                case 'coher', RR(:,tstep) = tmpX./abs(tmpX).^2;     % PHASE COHERENCE
                case 'phasecoher', RR(:,tstep) = tmpX./abs(tmpX);   % LINEAR COHERENCE 
            end
        end
    else
        printf('Please check your data, there are NaNs in it');
    end
end % tstep

